@@ -1,13 +1,12 @@
 package Pcore::DBH::DDL;
 
-use Pcore -role;
+use Pcore -role, -try;
 use Pcore::DBH::DDL::ChangeSet;
 
 requires qw[schema_info_sql];
 
 has dbh => ( is => 'ro', isa => ConsumerOf ['Pcore::DBH'], required => 1 );
 
-has dbc => ( is => 'lazy', isa => ConsumerOf ['Pcore::DBH'], init_arg => undef );    # effective dbh
 has _schema_info_table => ( is => 'lazy', isa => Str, default => '_schema_info', init_arg => undef );
 has _changesets => ( is => 'lazy', isa => HashRef, default => sub { {} }, init_arg => undef );
 
@@ -15,10 +14,6 @@ has _changesets => ( is => 'lazy', isa => HashRef, default => sub { {} }, init_a
 # revert all changes if one changeset failed
 # upgrade db to specified version, including downgrade - need to specify revert sql code
 
-sub _build_dbc($self) {
-    return $self->dbh->dbh;
-}
-
 sub add_changeset ( $self, %args ) {
     my $cset = Pcore::DBH::DDL::ChangeSet->new( \%args );
 
@@ -34,7 +29,7 @@ sub add_changeset ( $self, %args ) {
 sub upgrade ($self) {
     $self->_create_schema_info;
 
-    my $dbh = $self->dbc;
+    my $dbh = $self->dbh;
 
     my $info = $dbh->selectall_hashref( [ 'SELECT * FROM', [ $self->_schema_info_table ] ], key_cols => 'component' ) // {};
 
@@ -93,16 +88,6 @@ sub _get_cset_sql ( $self, $cset ) {
 }
 
 1;
-## -----SOURCE FILTER LOG BEGIN-----
-##
-## PerlCritic profile "pcore-script" policy violations:
-## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
-## | Sev. | Lines                | Policy                                                                                                         |
-## |======+======================+================================================================================================================|
-## |    3 | 41                   | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
-## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
-##
-## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
